==> Haraka-2.8.23.tgz: package/tests/fixtures/vm_harness.js <==

const fs   = require('fs');
const path = require('path');
const vm   = require('vm');

function dot_files (element) {
    return element.match(/^\./) == null;
}

exports.sandbox_require = function (id) {
    if (id[0] == '.' && id[1] != '.') {
        let override;
        try {
            override = path.join(__dirname, id + '.js');
            fs.statSync(override);
            id = override;
        }
        catch (e) {
            try {
                override = path.join(__dirname, '..', '..', 'outbound', id.replace(/^[./]*/, '') + '.js');
                fs.statSync(override);
                id = override;
            }
            catch (err) {
                id = '../../' + id.replace(/^[./]*/, '');
            }
        }
    }
    else if (id[0] == '.' && id[1] == '.') {
        id = '../../' + id.replace(/^[./]*/, '');
    }
    return require(id);
}

function make_test (module_path, test_path, additional_sandbox) {
    return function (test) {
        let code = fs.readFileSync(module_path);
        code += fs.readFileSync(test_path);
        const sandbox = {
            require: exports.sandbox_require,
            console: console,
            Buffer: Buffer,
            exports: {},
            test: test
        };
        Object.keys(additional_sandbox).forEach(function (k) {
            sandbox[k] = additional_sandbox[k];
        });
        vm.runInNewContext(code, sandbox);
    };
}

exports.add_tests = function (module_path, tests_path, test_exports, add_to_sandbox) {
    const additional_sandbox = add_to_sandbox || {};
    const tests = fs.readdirSync(tests_path).filter(dot_files);
    for (let x = 0; x < tests.length; x++) {
        test_exports[tests[x]] = make_test(module_path, tests_path + tests[x], additional_sandbox);
    }
}

==> Haraka-2.8.25.tgz: package/tests/fixtures/vm_harness.js <==

const fs   = require('fs');
const path = require('path');
const vm   = require('vm');

function dot_files (element) {
    return element.match(/^\./) == null;
}

exports.sandbox_require = id => {
    if (id[0] == '.' && id[1] != '.') {
        let override;
        try {
            override = path.join(__dirname, id + '.js');
            fs.statSync(override);
            id = override;
        }
        catch (e) {
            try {
                override = path.join(__dirname, '..', '..', 'outbound', id.replace(/^[./]*/, '') + '.js');
                fs.statSync(override);
                id = override;
            }
            catch (err) {
                id = '../../' + id.replace(/^[./]*/, '');
            }
        }
    }
    else if (id[0] == '.' && id[1] == '.') {
        id = '../../' + id.replace(/^[./]*/, '');
    }
    return require(id);
}

function make_test (module_path, test_path, additional_sandbox) {
    return test => {
        let code = fs.readFileSync(module_path);
        code += fs.readFileSync(test_path);
        const sandbox = {
            require: exports.sandbox_require,
            console,
            Buffer,
            exports: {},
            test
        };
        Object.keys(additional_sandbox).forEach(k => {
            sandbox[k] = additional_sandbox[k];
        });
        vm.runInNewContext(code, sandbox);
    };
}

exports.add_tests = (module_path, tests_path, test_exports, add_to_sandbox) => {
    const additional_sandbox = add_to_sandbox || {};
    const tests = fs.readdirSync(tests_path).filter(dot_files);
    for (let x = 0; x < tests.length; x++) {
        test_exports[tests[x]] = make_test(module_path, tests_path + tests[x], additional_sandbox);
    }
}
